@@ -7,23 +7,29 @@ setMethod(
     out <- sub("$TINYTABLE_TYPST_NCOL", ncol(x), out, fixed = TRUE)
     out <- sub("$TINYTABLE_TYPST_NHEAD", x@nhead, out, fixed = TRUE)
 
-
     cap <- x@caption
     if (length(cap) == 1) {
-      out <- sub("$TINYTABLE_TYPST_CAPTION", sprintf("caption: %s,", cap), out, fixed = TRUE)
+      out <- sub(
+        "$TINYTABLE_TYPST_CAPTION",
+        sprintf("caption: %s,", cap),
+        out,
+        fixed = TRUE
+      )
     } else {
       out <- sub("$TINYTABLE_TYPST_CAPTION", "", out, fixed = TRUE)
     }
 
-
     # Quarto cross-references
     if (isTRUE(check_dependency("knitr"))) {
       quarto_caption <- isTRUE(knitr::pandoc_to("typst")) &&
         isFALSE(getOption("tinytable_quarto_figure", default = FALSE))
-      (!is.null(knitr::opts_current$get()[["label"]]) ||
-        !is.null(knitr::opts_current$get()[["tbl-cap"]]))
+      (
+        !is.null(knitr::opts_current$get()[["label"]]) ||
+          !is.null(knitr::opts_current$get()[["tbl-cap"]])
+      )
       if (quarto_caption) {
-        out <- lines_drop_between(out,
+        out <- lines_drop_between(
+          out,
           regex_start = "// start figure preamble",
           regex_end = "// end figure preamble",
           fixed = TRUE
