@@ -25,9 +25,11 @@
 #' filename <- file.path(tempdir(), "table.tex")
 #' tt(mtcars[1:4, 1:4]) |> save_tt(filename)
 #'
-save_tt <- function(x,
-                    output,
-                    overwrite = get_option("tinytable_save_overwrite", default = FALSE)) {
+save_tt <- function(
+  x,
+  output,
+  overwrite = get_option("tinytable_save_overwrite", default = FALSE)
+) {
   assert_class(x, "tinytable")
   assert_string(output)
   assert_flag(overwrite)
@@ -71,7 +73,8 @@ save_tt <- function(x,
 
   file_ext <- tools::file_ext(output)
 
-  output_format <- switch(file_ext,
+  output_format <- switch(
+    file_ext,
     "png" = "html",
     "html" = "html",
     "pdf" = "latex",
@@ -82,7 +85,10 @@ save_tt <- function(x,
     "txt" = "markdown",
     "docx" = "markdown",
     "typ" = "typst",
-    stop("The supported file extensions are: .png, .html, .pdf, .tex, .typ, .qmd, .Rmd, .txt, .docx, and .md.", call. = FALSE)
+    stop(
+      "The supported file extensions are: .png, .html, .pdf, .tex, .typ, .qmd, .Rmd, .txt, .docx, and .md.",
+      call. = FALSE
+    )
   )
 
   # evaluate styles at the very end of the pipeline, just before writing
@@ -96,7 +102,8 @@ save_tt <- function(x,
     # probably webshot2's fault. we need to build in `output`
     tmp <- file.path(dirname(output), paste0(get_id(), ".html"))
     write(x@table_string, file = tmp)
-    webshot2::webshot(tmp,
+    webshot2::webshot(
+      tmp,
       file = output,
       selector = "body > div > table",
       zoom = 4,
@@ -122,11 +129,19 @@ save_tt <- function(x,
     # tinytex sometimes generates logfiles when there are warnings, e.g because
     # table is too wide. See #260.
     # We delete additional logfiles generated by tinytex
-    existing_log_files <- list.files(temp_wd, pattern = "\\.log$", full.names = TRUE)
+    existing_log_files <- list.files(
+      temp_wd,
+      pattern = "\\.log$",
+      full.names = TRUE
+    )
 
     # render
     engine <- get_option("tinytable_pdf_engine", default = "xelatex")
-    assert_choice(engine, c("xelatex", "pdflatex", "lualatex"), name = "tinytable_pdf_engine")
+    assert_choice(
+      engine,
+      c("xelatex", "pdflatex", "lualatex"),
+      name = "tinytable_pdf_engine"
+    )
     tinytex::latexmk(f, pdf_file = output, engine = engine)
 
     # clean
@@ -148,9 +163,6 @@ save_tt <- function(x,
   return(invisible(path.expand(output)))
 }
 
-
-
-
 latex_standalone <- "
 \\documentclass{standalone}
 \\usepackage{tabularray}
