@@ -121,44 +121,63 @@
 #' tt(mtcars[1:5, 1:4], theme = "void") |>
 #'   style_tt(tabularray_inner = inner)
 #'
-style_tt <- function(x,
-                     i = NULL,
-                     j = NULL,
-                     bold = FALSE,
-                     italic = FALSE,
-                     monospace = FALSE,
-                     underline = FALSE,
-                     strikeout = FALSE,
-                     color = NULL,
-                     background = NULL,
-                     fontsize = NULL,
-                     align = NULL,
-                     alignv = NULL,
-                     colspan = NULL,
-                     rowspan = NULL,
-                     indent = NULL,
-                     line = NULL,
-                     line_color = "black",
-                     line_width = 0.1,
-                     finalize = NULL,
-                     tabularray_inner = NULL,
-                     tabularray_outer = NULL,
-                     bootstrap_class = NULL,
-                     bootstrap_css = NULL,
-                     bootstrap_css_rule = NULL,
-                     output = NULL,
-                     ...) {
+style_tt <- function(
+  x,
+  i = NULL,
+  j = NULL,
+  bold = FALSE,
+  italic = FALSE,
+  monospace = FALSE,
+  underline = FALSE,
+  strikeout = FALSE,
+  color = NULL,
+  background = NULL,
+  fontsize = NULL,
+  align = NULL,
+  alignv = NULL,
+  colspan = NULL,
+  rowspan = NULL,
+  indent = NULL,
+  line = NULL,
+  line_color = "black",
+  line_width = 0.1,
+  finalize = NULL,
+  tabularray_inner = NULL,
+  tabularray_outer = NULL,
+  bootstrap_class = NULL,
+  bootstrap_css = NULL,
+  bootstrap_css_rule = NULL,
+  output = NULL,
+  ...
+) {
   out <- x
 
   assert_choice(alignv, c("t", "m", "b"), null.ok = TRUE)
 
   assert_style_tt(
-    x = out, i = i, j = j, bold = bold, italic = italic, monospace = monospace, underline = underline, strikeout = strikeout,
-    color = color, background = background, fontsize = fontsize, align = align,
-    colspan = colspan, rowspan = rowspan, indent = indent,
-    line = line, line_color = line_color, line_width = line_width,
-    tabularray_inner = tabularray_inner, tabularray_outer = tabularray_outer, bootstrap_css = bootstrap_css,
-    bootstrap_css_rule = bootstrap_css_rule)
+    x = out,
+    i = i,
+    j = j,
+    bold = bold,
+    italic = italic,
+    monospace = monospace,
+    underline = underline,
+    strikeout = strikeout,
+    color = color,
+    background = background,
+    fontsize = fontsize,
+    align = align,
+    colspan = colspan,
+    rowspan = rowspan,
+    indent = indent,
+    line = line,
+    line_color = line_color,
+    line_width = line_width,
+    tabularray_inner = tabularray_inner,
+    tabularray_outer = tabularray_outer,
+    bootstrap_css = bootstrap_css,
+    bootstrap_css_rule = bootstrap_css_rule
+  )
 
   if (isTRUE(i %in% c("notes", "caption"))) {
     tmp <- list(
@@ -183,14 +202,20 @@ style_tt <- function(x,
 
   sanity_align(align, i)
 
-  assert_choice(output, c("typst", "latex", "html", "markdown", "gfm"), null.ok = TRUE)
+  assert_choice(
+    output,
+    c("typst", "latex", "html", "markdown", "gfm"),
+    null.ok = TRUE
+  )
 
   if ("width" %in% names(list(...))) {
     stop("The `width` argument is now in the `tt()` function.", call. = FALSE)
   }
 
   # i is a logical matrix mask
-  if (is.matrix(i) && is.logical(i) && nrow(i) == nrow(x) && ncol(i) == ncol(x)) {
+  if (
+    is.matrix(i) && is.logical(i) && nrow(i) == nrow(x) && ncol(i) == ncol(x)
+  ) {
     assert_null(j)
     settings <- which(i == TRUE, arr.ind = TRUE)
     settings <- stats::setNames(data.frame(settings), c("i", "j"))
@@ -205,7 +230,8 @@ style_tt <- function(x,
   }
 
   settings[["color"]] <- if (is.null(color)) NA else as.vector(color)
-  settings[["background"]] <- if (is.null(background)) NA else as.vector(background)
+  settings[["background"]] <- if (is.null(background)) NA else
+    as.vector(background)
   settings[["fontsize"]] <- if (is.null(fontsize)) NA else as.vector(fontsize)
   settings[["alignv"]] <- if (is.null(alignv)) NA else alignv
   settings[["line"]] <- if (is.null(line)) NA else line
@@ -219,10 +245,14 @@ style_tt <- function(x,
   settings[["indent"]] <- if (is.null(indent)) NA else as.vector(indent)
   settings[["colspan"]] <- if (is.null(colspan)) NA else colspan
   settings[["rowspan"]] <- if (is.null(rowspan)) NA else rowspan
-  settings[["bootstrap_css_rule"]] <- if (!is.null(bootstrap_css_rule)) bootstrap_css_rule else NA
-  settings[["bootstrap_css"]] <- if (!is.null(bootstrap_css)) bootstrap_css else NA
-  settings[["tabularray_inner"]] <- if (!is.null(tabularray_inner)) tabularray_inner else NA
-  settings[["tabularray_outer"]] <- if (!is.null(tabularray_outer)) tabularray_outer else NA
+  settings[["bootstrap_css_rule"]] <- if (!is.null(bootstrap_css_rule))
+    bootstrap_css_rule else NA
+  settings[["bootstrap_css"]] <- if (!is.null(bootstrap_css)) bootstrap_css else
+    NA
+  settings[["tabularray_inner"]] <- if (!is.null(tabularray_inner))
+    tabularray_inner else NA
+  settings[["tabularray_outer"]] <- if (!is.null(tabularray_outer))
+    tabularray_outer else NA
 
   if (!is.null(align)) {
     if (nchar(align) == length(jval)) {
@@ -232,13 +262,28 @@ style_tt <- function(x,
         stop(msg, call. = FALSE)
       }
       align_string <- data.frame(j = jval, align = align_string)
-      settings <- merge(settings, align_string, by = "j", all.x = TRUE, sort = FALSE)
+      settings <- merge(
+        settings,
+        align_string,
+        by = "j",
+        all.x = TRUE,
+        sort = FALSE
+      )
     } else if (nchar(align) == 1) {
       assert_choice(align, c("c", "l", "r", "d"))
       align_string <- data.frame(j = jval, align = align)
-      settings <- merge(settings, align_string, by = "j", all.x = TRUE, sort = FALSE)
+      settings <- merge(
+        settings,
+        align_string,
+        by = "j",
+        all.x = TRUE,
+        sort = FALSE
+      )
     } else {
-      msg <- sprintf("`align` must be a single character or a string of length %s.", length(jval))
+      msg <- sprintf(
+        "`align` must be a single character or a string of length %s.",
+        length(jval)
+      )
       stop(msg, call. = FALSE)
     }
   } else {
@@ -255,7 +300,11 @@ style_tt <- function(x,
     settings <- settings[!empty, , drop = FALSE]
   }
 
-  if (nrow(out@style) > 0 && nrow(settings) > 0 && ncol(out@style) != ncol(settings)) {
+  if (
+    nrow(out@style) > 0 &&
+      nrow(settings) > 0 &&
+      ncol(out@style) != ncol(settings)
+  ) {
     a <- out@style
     b <- settings
     if (!"tabularray" %in% colnames(a)) a$tabularray <- ""
@@ -278,31 +327,31 @@ style_tt <- function(x,
   return(out)
 }
 
-
-
-assert_style_tt <- function(x,
-                            i,
-                            j,
-                            bold,
-                            italic,
-                            monospace,
-                            underline,
-                            strikeout,
-                            color,
-                            background,
-                            fontsize,
-                            align,
-                            colspan,
-                            rowspan,
-                            indent,
-                            line,
-                            line_color,
-                            line_width,
-                            tabularray_inner,
-                            tabularray_outer,
-                            bootstrap_class = NULL,
-                            bootstrap_css = NULL,
-                            bootstrap_css_rule = NULL) {
+assert_style_tt <- function(
+  x,
+  i,
+  j,
+  bold,
+  italic,
+  monospace,
+  underline,
+  strikeout,
+  color,
+  background,
+  fontsize,
+  align,
+  colspan,
+  rowspan,
+  indent,
+  line,
+  line_color,
+  line_width,
+  tabularray_inner,
+  tabularray_outer,
+  bootstrap_class = NULL,
+  bootstrap_css = NULL,
+  bootstrap_css_rule = NULL
+) {
   assert_integerish(colspan, len = 1, lower = 2, null.ok = TRUE)
   assert_integerish(rowspan, len = 1, lower = 2, null.ok = TRUE)
   assert_numeric(indent, len = 1, lower = 0, null.ok = TRUE)
@@ -369,9 +418,21 @@ assert_style_tt <- function(x,
 
     # 1 or #cells
   } else if (!inull && !jnull) {
-    assert_length(color, len = c(1, length(ival) * length(jval)), null.ok = TRUE)
-    assert_length(background, len = c(1, length(ival) * length(jval)), null.ok = TRUE)
-    assert_length(fontsize, len = c(1, length(ival) * length(jval)), null.ok = TRUE)
+    assert_length(
+      color,
+      len = c(1, length(ival) * length(jval)),
+      null.ok = TRUE
+    )
+    assert_length(
+      background,
+      len = c(1, length(ival) * length(jval)),
+      null.ok = TRUE
+    )
+    assert_length(
+      fontsize,
+      len = c(1, length(ival) * length(jval)),
+      null.ok = TRUE
+    )
     assert_length(bold, len = c(1, length(ival) * length(jval)))
     assert_length(italic, len = c(1, length(ival) * length(jval)))
     assert_length(monospace, len = c(1, length(ival) * length(jval)))
