@@ -1,15 +1,20 @@
 theme_default <- function(x, ...) {
   fn <- theme_placement_factory(
     horizontal = get_option("tinytable_theme_default_horizontal", "c"),
-    latex_float = get_option("tinytable_theme_placement_latex_float", default = NULL)
+    latex_float = get_option(
+      "tinytable_theme_placement_latex_float",
+      default = NULL
+    )
   )
   x <- style_tt(x, finalize = fn)
 
   if (isTRUE(x@output %in% c("html", "typst"))) {
     col <- if (x@output == "typst") "black" else "#d3d8dc"
-    bc <- if (length(x@bootstrap_class) == 0) "table table-borderless" else x@bootstrap_class
+    bc <- if (length(x@bootstrap_class) == 0) "table table-borderless" else
+      x@bootstrap_class
     # top
-    x <- style_tt(x,
+    x <- style_tt(
+      x,
       bootstrap_class = bc,
       i = -x@nhead + 1,
       line = "t",
@@ -18,7 +23,8 @@ theme_default <- function(x, ...) {
     )
     # mid
     if (length(x@names) > 0) {
-      x <- style_tt(x,
+      x <- style_tt(
+        x,
         bootstrap_class = bc,
         i = 0,
         line = "b",
@@ -27,7 +33,8 @@ theme_default <- function(x, ...) {
       )
     }
     # bottom
-    x <- style_tt(x,
+    x <- style_tt(
+      x,
       bootstrap_class = bc,
       i = nrow(x),
       line = "b",
