@@ -61,15 +61,17 @@
 #' tt(k, digits = 2)
 #'
 #' @export
-tt <- function(x,
-               digits = get_option("tinytable_tt_digits", default = NULL),
-               caption = get_option("tinytable_tt_caption", default = NULL),
-               notes = get_option("tinytable_tt_notes", default = NULL),
-               width = get_option("tinytable_tt_width", default = NULL),
-               theme = get_option("tinytable_tt_theme", default = "default"),
-               rownames = get_option("tinytable_tt_rownames", default = FALSE),
-               escape = get_option("tinytable_tt_escape", default = FALSE),
-               ...) {
+tt <- function(
+  x,
+  digits = get_option("tinytable_tt_digits", default = NULL),
+  caption = get_option("tinytable_tt_caption", default = NULL),
+  notes = get_option("tinytable_tt_notes", default = NULL),
+  width = get_option("tinytable_tt_width", default = NULL),
+  theme = get_option("tinytable_tt_theme", default = "default"),
+  rownames = get_option("tinytable_tt_rownames", default = FALSE),
+  escape = get_option("tinytable_tt_escape", default = FALSE),
+  ...
+) {
   dots <- list(...)
 
   # sanity checks
@@ -133,7 +135,8 @@ tt <- function(x,
   tab <- data.frame(lapply(tab, trimws))
   colnames(tab) <- colnames(x)
 
-  out <- methods::new("tinytable",
+  out <- methods::new(
+    "tinytable",
     data = x,
     table = tab,
     caption = caption,
