@@ -2,7 +2,9 @@ setMethod(
   f = "tt_eval",
   signature = "tinytable_bootstrap",
   definition = function(x, ...) {
-    template <- readLines(system.file("templates/bootstrap.html", package = "tinytable"))
+    template <- readLines(
+      system.file("templates/bootstrap.html", package = "tinytable")
+    )
 
     mathjax <- get_option("tinytable_html_mathjax", default = FALSE)
     assert_flag(mathjax, name = "tinytable_html_mathjax")
@@ -14,10 +16,14 @@ setMethod(
       template <- strsplit(template, "\n")[[1]]
     }
 
-    quartoprocessing <- get_option("tinytable_quarto_disable_processing", default = TRUE)
+    quartoprocessing <- get_option(
+      "tinytable_quarto_disable_processing",
+      default = TRUE
+    )
     assert_flag(quartoprocessing, name = "tinytable_quarto_disable_processing")
     if (isFALSE(quartoprocessing)) {
-      template <- sub("data-quarto-disable-processing='true'",
+      template <- sub(
+        "data-quarto-disable-processing='true'",
         "data-quarto-disable-processing='false'",
         template,
         fixed = TRUE
@@ -70,7 +76,11 @@ setMethod(
             )
           }
         } else {
-          tmp <- sprintf("<tr><td colspan='%s'>%s</td></tr>", ncol(x), x@notes[[k]])
+          tmp <- sprintf(
+            "<tr><td colspan='%s'>%s</td></tr>",
+            ncol(x),
+            x@notes[[k]]
+          )
         }
         notes_tmp <- c(notes_tmp, tmp)
       }
@@ -91,14 +101,20 @@ setMethod(
     if (length(x@width) == 1) {
       template <- sub(
         "width: auto;",
-        sprintf("table-layout: fixed; width: %s%% !important;", round(x@width * 100)),
+        sprintf(
+          "table-layout: fixed; width: %s%% !important;",
+          round(x@width * 100)
+        ),
         template,
         fixed = TRUE
       )
     } else if (length(x@width) > 1) {
       template <- sub(
         "width: auto;",
-        sprintf("table-layout: fixed; width: %s%% !important;", round(sum(x@width) * 100)),
+        sprintf(
+          "table-layout: fixed; width: %s%% !important;",
+          round(sum(x@width) * 100)
+        ),
         template,
         fixed = TRUE
       )
@@ -109,9 +125,24 @@ setMethod(
     x@id <- id
 
     # table and styling function in JS must have different names when there is more than one table on a page.
-    template <- gsub("styleCell", paste0("styleCell_", id), template, fixed = TRUE)
-    template <- gsub("spanCell", paste0("spanCell_", id), template, fixed = TRUE)
-    template <- gsub("$tinytable_TABLE_ID", paste0("tinytable_", id), template, fixed = TRUE)
+    template <- gsub(
+      "styleCell",
+      paste0("styleCell_", id),
+      template,
+      fixed = TRUE
+    )
+    template <- gsub(
+      "spanCell",
+      paste0("spanCell_", id),
+      template,
+      fixed = TRUE
+    )
+    template <- gsub(
+      "$tinytable_TABLE_ID",
+      paste0("tinytable_", id),
+      template,
+      fixed = TRUE
+    )
 
     # header
     idx <- grep("$tinytable_BOOTSTRAP_HEADER", template, fixed = TRUE)
@@ -150,7 +181,11 @@ setMethod(
     x@table_string <- out
 
     if (length(x@bootstrap_class) == 0) {
-      if (is.null(x@theme[[1]]) || is.function(x@theme[[1]]) || isTRUE("default" %in% x@theme[[1]])) {
+      if (
+        is.null(x@theme[[1]]) ||
+          is.function(x@theme[[1]]) ||
+          isTRUE("default" %in% x@theme[[1]])
+      ) {
         x <- theme_tt(x, "default")
       }
     } else if (is.character(x@theme[[1]])) {
@@ -173,9 +208,8 @@ setMethod(
     }
 
     return(x)
-  })
-
-
+  }
+)
 
 bootstrap_setting <- function(x, new, component = "row") {
   att <- attributes(x)
