@@ -2,7 +2,9 @@ setMethod(
   f = "tt_eval",
   signature = "tinytable_tabularray",
   definition = function(x, ...) {
-    template <- readLines(system.file("templates/tabularray.tex", package = "tinytable"))
+    template <- readLines(
+      system.file("templates/tabularray.tex", package = "tinytable")
+    )
 
     ncols <- ncol(x)
     nrows <- nrow(x)
@@ -11,12 +13,15 @@ setMethod(
     if (length(x@caption) > 0) tall <- TRUE
     if (length(x@notes) > 0) tall <- TRUE
 
-
     # placement
     if (length(x@placement) == 1) {
       assert_string(x@placement)
       # dollar sign to avoid [H][H] when we style multiple times
-      template <- sub("\\\\begin\\{table\\}", sprintf("\\\\begin{table}[%s]\n", x@placement), template)
+      template <- sub(
+        "\\\\begin\\{table\\}",
+        sprintf("\\\\begin{table}[%s]\n", x@placement),
+        template
+      )
     }
 
     # body: main
@@ -31,10 +36,15 @@ setMethod(
 
     # theme: booktabs
     th <- x@theme[[1]]
-    if (is.null(th) || is.function(th) || isTRUE(th %in% c("default", "striped"))) {
+    if (
+      is.null(th) || is.function(th) || isTRUE(th %in% c("default", "striped"))
+    ) {
       if (length(colnames(x)) > 0) {
         # %% are important to distinguish between potentially redundant data rows
-        header[length(header)] <- paste(header[length(header)], "\\midrule %% TinyTableHeader")
+        header[length(header)] <- paste(
+          header[length(header)],
+          "\\midrule %% TinyTableHeader"
+        )
       }
     }
 
@@ -75,7 +85,11 @@ setMethod(
     if (length(x@notes) > 0) {
       if (length(x@caption) == 0) {
         # otherwise an empty caption is created automatically
-        out <- tabularray_insert(out, content = "entry=none,label=none", type = "outer")
+        out <- tabularray_insert(
+          out,
+          content = "entry=none,label=none",
+          type = "outer"
+        )
       }
       if (is.null(names(x@notes))) {
         lab <- sapply(seq_along(x@notes), function(k) strrep(" ", k - 1))
